Exit codes — AiiDA-FLEUR 1.1.0 documentation

# Exit codes

AiiDA processes return a special object upon termination - an exit code. Basically, there are two types of exit-codes: non-zero and zero ones. If a process returned a zero exit code it has finished successfully. In contrast, non-zero exit code means there were a problem.

For example, there are 2 processes shown below:

    (aiidapy)$ verdi process list -a -p 1
       PK  Created    State             Process label             Process status
     ----  ---------  ----------------  ------------------------  ----------------------------------
       60  3m ago     ⏹ Finished [0]    FleurCalculation
       68  3m ago     ⏹ Finished [302]  FleurCalculation

The first calculation was successful and the second one failed and threw exit code 302, which means it could not open one of the output files for some reason.

For more detailed information, see AiiDA documentation.

The list of all exit codes implemented in AiiDA-FLEUR:

Exit code | Exit message | Thrown by
230 | Invalid workchain parameters | CreateMagnetic
230 | Invalid workchain parameters | DMI
230 | Invalid workchain parameters | EOS
230 | Invalid workchain parameters | MAE
230 | Invalid workchain parameters | MAE Conv
230 | Invalid workchain parameters | Relax
230 | Invalid workchain parameters | SCF
230 | Invalid workchain parameters | SSDisp
230 | Invalid workchain parameters | SSDisp Conv
231 | Invalid input configuration | CreateMagnetic
231 | Invalid input configuration | DMI
231 | Invalid input configuration | MAE
231 | Invalid input configuration | SCF
231 | Invalid input configuration | SSDisp
233 | Input codes do not correspond to fleur or inpgen codes respectively. | DMI
233 | Input codes do not correspond to fleur or inpgen codes respectively. | MAE
233 | Input codes do not correspond to fleur or inpgen codes respectively. | SSDisp
235 | Input file modification failed. | DMI
235 | Input file modification failed. | MAE
235 | Input file modification failed | SCF
235 | Input file modification failed. | SSDisp
236 | Input file was corrupted after modifications | DMI
236 | Input file was corrupted after modifications | MAE
236 | Input file was corrupted after modifications | SCF
236 | Input file was corrupted after modifications | SSDisp
300 | No retrieved folder found | FleurCalculation
300 | No retrieved folder found | FleurCalculation
300 | No retrieved folder found | FleurinpgenCalculation
300 | No retrieved folder found | FleurinpgenCalculation
301 | One of the output files can not be opened | FleurCalculation
301 | One of the output files can not be opened | FleurinpgenCalculation
302 | FLEUR calculation failed for unknown reason | FleurCalculation
303 | XML output file was not found | FleurCalculation
304 | Parsing of XML output file failed | FleurCalculation
305 | Parsing of relax XML output file failed | FleurCalculation
306 | XML input file was not found | FleurinpgenCalculation
310 | FLEUR calculation failed due to memory issue | FleurCalculation
311 | FLEUR calculation failed because atoms spilled to the vacuum | FleurBase
311 | FLEUR calculation failed because atoms spilled to the vacuum | FleurCalculation
311 | FLEUR calculation failed because atoms spilled to the vacuum | Relax
312 | FLEUR calculation failed due to MT overlap | FleurCalculation
313 | Overlapping MT-spheres during relaxation | FleurBase
313 | Overlapping MT-spheres during relaxation | FleurCalculation
313 | Overlapping MT-spheres during relaxation | Relax
314 | Problem with cdn is suspected | Relax
334 | Reference calculation failed. | DMI
334 | Reference calculation failed. | MAE
334 | Reference calculation failed. | SSDisp
335 | Found no reference calculation remote repository. | DMI
335 | Found no reference calculation remote repository. | MAE
335 | Found no reference calculation remote repository. | SSDisp
336 | Force theorem calculation failed. | DMI
336 | Force theorem calculation failed. | MAE
336 | Force theorem calculation failed. | SSDisp
340 | Convergence SSDisp calculation failed for all q-vectors | SSDisp conv
341 | Convergence SSDisp calculation failed for some q-vectors | SSDisp conv
343 | Convergence MAE calculation failed for all SQAs | MAE conv
344 | Convergence MAE calculation failed for some SQAs | MAE conv
350 | The workchain execution did not lead to relaxation criterion. Thrown in the very end of the workchain. | Relax
351 | SCF Workchains failed for some reason. | Relax
352 | Found no relaxed structure info in the output of SCF | Relax
353 | Found no SCF output | Relax
354 | Force is small, switch to BFGS | Relax
360 | Inpgen calculation failed | SCF
361 | Fleur calculation failed | SCF
380 | Specified substrate is not bcc or fcc, only them are supported | CreateMagnetic
382 | Relaxation calculation failed. | CreateMagnetic
383 | EOS WorkChain failed. | CreateMagnetic
389 | FLEUR calculation failed due to memory issue and it can not be solved for this scheduler | FleurBase
390 | check_kpts() suggests less than 60% of node load | FleurBase
399 | FleurCalculation failed and FleurBaseWorkChain has no strategy to resolve this | FleurBase
399 | FleurRelaxWorkChain failed and FleurBaseRelaxWorkChain has no strategy to resolve this | Relax Base